<?php
/**
 * Thinker Theme Customizer
 *
 * @package Thinker
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function thinker_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
/**
 * Adds the individual sections for custom logo
 */
   $wp_customize->add_section( 'thinker_logo_section' , array(
    'title'       => __( 'Logo', 'thinker' ),
    'priority'    => 30,
    'description' => 'Upload a logo to replace the default site name and description in the header',
) );
$wp_customize->add_setting( 'thinker_logo', array(
	'sanitize_callback' => 'esc_url_raw',
) );
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'thinker_logo', array(
    'label'    => __( 'Logo', 'thinker' ),
    'section'  => 'thinker_logo_section',
    'settings' => 'thinker_logo',
) ) );
/*-----------------------------------------------------------------------------------*/
/*	Adds the individual sections, settings, and controls to the theme customizer
/*-----------------------------------------------------------------------------------*/
    $wp_customize->add_section(
        'thinker_section_one',
        array(
            'title' => 'Copyright Settings',
            'description' => 'This is a settings section.',
            'priority' => 31,
        )
    );
	$wp_customize->add_setting(
    'copyright_textbox',
    array(
        'default' => 'The Thinker by Anariel Design. All rights reserved.',
		'sanitize_callback' => 'thinker_sanitize_text',
    )
);
$wp_customize->add_control(
    'copyright_textbox',
    array(
        'label' => 'Copyright text',
        'section' => 'thinker_section_one',
        'type' => 'text',
    )
);
$wp_customize->add_setting(
    'hide_copyright',
	array(
	'sanitize_callback' => 'thinker_sanitize_checkbox',
    )
);
$wp_customize->add_control(
    'hide_copyright',
    array(
        'type' => 'checkbox',
        'label' => 'Hide copyright text',
        'section' => 'thinker_section_one',
    )
);
/**
 * Adds the individual sections for custom favicon
 */
   $wp_customize->add_section( 'thinker_favicon_section' , array(
    'title'       => __( 'Favicon', 'thinker' ),
    'priority'    => 32,
    'description' => 'Upload a favicon',
) );
$wp_customize->add_setting( 
	'thinker_favicon',
	array(
	'sanitize_callback' => 'esc_url_raw',
	)
);
$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'thinker_favicon', array(
    'label'    => __( 'Favicon', 'thinker' ),
    'section'  => 'thinker_favicon_section',
    'settings' => 'thinker_favicon',
) ) );
}
add_action( 'customize_register', 'thinker_customize_register' );
/**
 * Sanitization
 */
//Checkboxes
function thinker_sanitize_checkbox( $input ) {
	if ( $input == 1 ) {
		return 1;
	} else {
		return '';
	}
}
//Integers
function thinker_sanitize_int( $input ) {
    if( is_numeric( $input ) ) {
        return intval( $input );
    }
}
//Text
function thinker_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}
//No sanitize - empty function for options that do not require sanitization -> to bypass the Theme Check plugin
function thinker_no_sanitize( $input ) {
}
/**
 * Sanitize the dropdown pages.
 *
 * @param interger $input.
 * @return interger.
 */
function thinker_sanitize_dropdown_pages( $input ) {
	if ( is_numeric( $input ) ) {
		return intval( $input );
	}
}